#' Default template of a schema description
#'
#' @format The object of class \code{schema} describes at which position in a
#'   table which information can be found. It contains the four slots
#'   \code{clusters}, \code{header}, \code{meta} and \code{variables}.
#'
#'   The default schema description contains an example of an identifying and a
#'   values variables. Further identifying and values variables would be added
#'   when more variables are contained in a table.
#'
"schema_default"

#' List of table types
#'
#' @format The object of class \code{list} contains 20 different types of tables
#'   that are used throughout the unit-tests and examples/vignette.
"tabs2shift"